@@ -24,13 +24,14 @@ from warnings import warn
 import click
 from jsonref import JsonRef
 import yaml
+from requests import Request
 from civis.cli._cli_commands import (
     civis_ascii_art, files_download_cmd, files_upload_cmd,
     jobs_follow_log, jobs_follow_run_log, notebooks_download_cmd,
     notebooks_new_cmd, notebooks_up, notebooks_down, notebooks_open, sql_cmd)
 from civis.resources import get_api_spec, CACHED_SPEC_PATH
 from civis.resources._resources import parse_method_name
-from civis._utils import open_session
+from civis._utils import open_session, retry_request, MAX_RETRIES
 
 
 _REPLACEABLE_COMMAND_CHARS = re.compile(r'[^A-Za-z0-9]+')
@@ -160,7 +161,9 @@ def invoke(method, path, op, *args, **kwargs):
         method=method
     )
     with open_session(get_api_key(), user_agent=CLI_USER_AGENT) as sess:
-        response = sess.request(**request_info)
+        request = Request(**request_info)
+        pre_request = sess.prepare_request(request)
+        response = retry_request(method, pre_request, sess, MAX_RETRIES)
 
     # Print the response to stderr and set exit code to 1 if there was an error
     output_file = sys.stdout
