@@ -662,10 +662,13 @@ def dataframe_to_civis(df, database, table, api_key=None, client=None,
     sortkey2 : str, optional
         The second column in a compound sortkey for the table.
     table_columns : list[Dict[str, str]], optional
-        A list of dictionaries corresponding to the columns in
-        the source file. Each dictionary should have keys
-        for column "name" and "sqlType". The import will only copy these
-        columns regardless if there are more columns in the table.
+        An array of hashes corresponding to the columns in the order
+        they appear in the source file. Each hash should have keys for
+        database column "name" and "sqlType". This parameter is
+        required if the table does not exist, the table is being dropped,
+        or the columns in the source file do not appear in the same order
+        as in the destination table. The "sqlType" key is not required
+        when appending to an existing table.
     headers : bool, optional [DEPRECATED]
         Whether or not the first row of the file should be treated as
         headers. The default, ``None``, attempts to autodetect whether
@@ -805,10 +808,13 @@ def csv_to_civis(filename, database, table, api_key=None, client=None,
     sortkey2 : str, optional
         The second column in a compound sortkey for the table.
     table_columns : list[Dict[str, str]], optional
-        A list of dictionaries corresponding to the columns in
-        the source file. Each dictionary should have keys
-        for column "name" and "sqlType". The import will only copy these
-        columns regardless if there are more columns in the table.
+        An array of hashes corresponding to the columns in the order
+        they appear in the source file. Each hash should have keys for
+        database column "name" and "sqlType". This parameter is
+        required if the table does not exist, the table is being dropped,
+        or the columns in the source file do not appear in the same order
+        as in the destination table. The "sqlType" key is not required
+        when appending to an existing table.
     delimiter : string, optional
         The column delimiter. One of ``','``, ``'\\t'`` or ``'|'``.
     headers : bool, optional
@@ -934,10 +940,13 @@ def civis_file_to_table(file_id, database, table, client=None,
     sortkey2 : str, optional
         The second column in a compound sortkey for the table.
     table_columns : list[Dict[str, str]], optional
-        A list of dictionaries corresponding to the columns in
-        the source file. Each dictionary should have keys
-        for column "name" and "sqlType". The import will only copy these
-        columns regardless if there are more columns in the table.
+        An array of hashes corresponding to the columns in the order
+        they appear in the source file. Each hash should have keys for
+        database column "name" and "sqlType". This parameter is
+        required if the table does not exist, the table is being dropped,
+        or the columns in the source file do not appear in the same order
+        as in the destination table. The "sqlType" key is not required
+        when appending to an existing table.
     primary_keys: list[str], optional
         A list of the primary key column(s) of the destination table that
         uniquely identify a record. These columns must not contain null values.
@@ -997,7 +1006,7 @@ def civis_file_to_table(file_id, database, table, client=None,
     if client is None:
         client = APIClient()
 
-    schema, table = split_schema_tablename(table)
+    schema, table_name = split_schema_tablename(table)
     if isinstance(file_id, int):
         file_id = [file_id]
     if schema is None:
@@ -1018,10 +1027,21 @@ def civis_file_to_table(file_id, database, table, client=None,
     except ValueError:
         table_exists = False
 
+    sql_types_provided = False
+    if table_columns:
+        sql_type_cnt = sum(1 for col in table_columns if col.get('sql_type'))
+        if sql_type_cnt == len(table_columns):
+            sql_types_provided = True
+        elif sql_type_cnt != 0:
+            error_message = 'Some table columns ' \
+                           'have a sql type provided, ' \
+                           'but others do not.'
+            raise ValueError(error_message)
+
     # Use Preprocess endpoint to get the table columns as needed
     # and perform necessary file cleaning
     need_table_columns = ((not table_exists or existing_table_rows == 'drop')
-                          and table_columns is None)
+                          and (not sql_types_provided))
 
     cleaning_futures = _run_cleaning(file_id, client, need_table_columns,
                                      headers, delimiter, hidden)
@@ -1031,23 +1051,25 @@ def civis_file_to_table(file_id, database, table, client=None,
         cleaning_futures, client, headers, need_table_columns, delimiter
     )
 
-    table_columns = table_columns or cleaned_table_columns
+    table_columns = (cleaned_table_columns if need_table_columns
+                     else table_columns)
 
     source = dict(file_ids=cleaned_file_ids)
-    destination = dict(schema=schema, table=table, remote_host_id=db_id,
+    destination = dict(schema=schema, table=table_name, remote_host_id=db_id,
                        credential_id=cred_id, primary_keys=primary_keys,
                        last_modified_keys=last_modified_keys)
 
     redshift_options = dict(distkey=distkey, sortkeys=[sortkey1, sortkey2],
                             diststyle=diststyle)
 
-    # If multiple files are being imported, there might be differences in
+    # If multiple files are being imported and the user hasn't explicitly
+    # provided table column info, then there might be differences in
     # their precisions/lengths - setting this option will allow the Civis API
     # to increase these values for the data types provided, and decreases the
-    # risk of a length-related import failure
-    loosen_types = len(file_id) > 1
+    # risk of a length-related import failure when types are inferred.
+    loosen_types = need_table_columns and len(file_id) > 1
 
-    import_name = 'CSV import to {}.{}'.format(schema, table)
+    import_name = 'CSV import to {}.{}'.format(schema, table_name)
     import_job = client.imports.post_files_csv(
         source,
         destination,
@@ -1263,8 +1285,11 @@ def _run_cleaning(file_ids, client, need_table_columns, headers, delimiter,
             column_delimiter=delimiter,
             hidden=hidden
         )
-        cleaning_futures.append(run_job(cleaner_job.id, client=client,
-                                        polling_interval=polling_interval))
+        fut = run_job(cleaner_job.id, client=client,
+                      polling_interval=polling_interval)
+        log.debug('Started run %d for pre process job %d',
+                  fut.run_id, cleaner_job.id)
+        cleaning_futures.append(fut)
     return cleaning_futures
 
 
