@@ -11,15 +11,18 @@ except ImportError:
 
 from jsonref import JsonRef
 import requests
+from requests import Request
 
 from civis.base import Endpoint, get_base_url
 from civis._deprecation import deprecate_param
 from civis._utils import (camel_to_snake, to_camelcase,
-                          open_session, get_api_key)
+                          open_session, get_api_key,
+                          retry_request, MAX_RETRIES)
 
 
 API_VERSIONS = ["1.0"]
 BASE_RESOURCES_V1 = [
+    'aliases',
     'announcements',
     'apps',
     'civis',
@@ -31,9 +34,11 @@ BASE_RESOURCES_V1 = [
     'enhancements',
     'exports',
     'files',
+    'git_repos',
     'groups',
     'imports',
     'jobs',
+    'json_values',
     'match_targets',
     'media',
     'models',
@@ -48,6 +53,8 @@ BASE_RESOURCES_V1 = [
     'results',
     'scripts',
     'search',
+    'services',
+    'storage_hosts',
     'tables',
     'templates',
     'users',
@@ -60,7 +67,6 @@ ITERATOR_PARAM_DESC = (
     "    If True, return a generator to iterate over all responses. Use when\n"
     "    more results than the maximum allowed by limit are needed. When\n"
     "    True, limit and page_num are ignored. Defaults to False.\n")
-MAX_RETRIES = 10
 CACHED_SPEC_PATH = os.path.join(os.path.expanduser('~'),
                                 ".civis_api_spec.json")
 
@@ -499,8 +505,10 @@ def get_api_spec(api_key, api_version="1.0", user_agent="civis-python"):
         API client version tag and ``requests`` version tag.
     """
     if api_version == "1.0":
-        with open_session(api_key, MAX_RETRIES, user_agent=user_agent) as sess:
-            response = sess.get("{}endpoints".format(get_base_url()))
+        with open_session(api_key, user_agent=user_agent) as sess:
+            request = Request('GET', "{}endpoints".format(get_base_url()))
+            pre_request = sess.prepare_request(request)
+            response = retry_request('get', pre_request, sess, MAX_RETRIES)
     else:
         msg = "API specification for api version {} cannot be found"
         raise ValueError(msg.format(api_version))
